@@ -37,6 +37,6 @@ dm_bind <- function(..., repair = "check_unique", quiet = FALSE) {
   dms_renamed <- map2(dms, renaming_recipe, dm_rename_tbl)
 
   new_defs <- map(dms_renamed, dm_get_def)
-  vctrs::vec_rbind(!!!new_defs) %>%
+  vec_rbind(!!!new_defs) %>%
     new_dm3()
 }
