@@ -46,3 +46,14 @@ expect_condition_obj <- function(object, regexp = NULL, class = NULL, ...,
     label = label)
   invisible(obj)
 }
+
+expect_deprecated_obj <- function(object, regexp = NULL, ...,
+                                  info = NULL, label = NULL) {
+  lifecycle::expect_deprecated(
+    obj <- rlang::eval_tidy({{ object }}),
+    regexp = regexp,
+    ...,
+    info = info,
+    label = label)
+  invisible(obj)
+}
